.. contents::

Introduction
============

Zope is an open-source web application server.

This document provides some general information about Zope and provides
links to other documents.

Installation information can be found in ``docs/INSTALL.rst``.  Other
documentation is also in the "docs" directory and in the Zope
documentation section at https://zope.readthedocs.io .

Installation
============

Follow the instructions in ``docs/INSTALL.rst`` to install Zope.

If you do not have a source checkout with docs, you can find the latest
install docs online at
https://zope.readthedocs.io/en/latest/INSTALL-buildout.html

Note that you *cannot* simply do ``pip install zope2``, because you need
specific versions of all dependencies. Follow the documentation to
ensure you get the correct versions, or else installation is very
likely to fail.

License
=======

The Zope License is included in ``LICENSE.txt``.

Bug tracker
===========

Bugs reports should be made through the Zope bugtracker at
https://github.com/zopefoundation/Zope/issues.  A bug report should
contain detailed information about how to reproduce the bug.
